@@ -1,12 +1,10 @@
 """
 API (ObjectClerk) definition
 """
-import json
 import logging
 from hashlib import md5
 from io import BufferedReader
 from io import BytesIO
-from os import environ
 from pathlib import Path
 from typing import List
 from typing import Optional
@@ -14,14 +12,14 @@ from typing import Tuple
 from typing import Union
 
 from boto3 import client as Boto3Client
-from boto3.s3.transfer import TransferConfig as BotoTransferConfig
-from botocore.config import Config as BotoConfig
-from botocore.exceptions import ConnectionError
-from botocore.exceptions import HTTPClientError
 from retry import retry
 from retry.api import retry_call
 
-from object_clerk.exceptions import ObjectClerkServerInternalException
+from object_clerk.config import CHECKSUM_RETRY_CONFIG
+from object_clerk.config import CLIENT_CONFIG
+from object_clerk.config import CONNECTION_RETRY_EXCEPTIONS
+from object_clerk.config import MULTIPART_THRESHOLD
+from object_clerk.config import UPLOAD_CONFIG
 from object_clerk.exceptions import ObjectSaveException
 from object_clerk.exceptions import ObjectVerificationException
 from object_clerk.utils import mutate_client_exceptions
@@ -29,19 +27,6 @@ from object_clerk.utils import mutate_client_exceptions
 logger = logging.getLogger(__name__)
 
 # Configure boto to not retry; handled by the retry api
-BOTO_CONFIG = BotoConfig(connect_timeout=60, read_timeout=60, retries={"max_attempts": 0})
-
-# Exceptions to retry according to the instance definition
-CONNECTION_RETRY_EXCEPTIONS = (ConnectionError, HTTPClientError, ObjectClerkServerInternalException)
-
-# Set threshold at which the md5 checksum isn't valid to compare
-# to the etag due to multipart uploads
-MB_500 = 1024 * 1024 * 500  # 500 MB
-MULTIPART_THRESHOLD = int(environ.get("MULTIPART_THRESHOLD", MB_500))
-CHECKSUM_RETRY_CONFIG = json.loads(environ.get("CHECKSUM_RETRY_CONFIG", "null")) or {
-    "tries": 3,
-    "delay": 1,
-}
 
 
 __all__ = ["ObjectClerk"]
@@ -110,15 +95,12 @@ class ObjectClerk:
         }
         protocol = "https" if self.use_ssl else "http"
         self.endpoint_url = f"{protocol}://{self.host}:{self.port}"
-        self.transfer_config = BotoTransferConfig(
-            multipart_threshold=MULTIPART_THRESHOLD, multipart_chunksize=MULTIPART_THRESHOLD
-        )
         self.client = Boto3Client(
             service_name="s3",
             aws_access_key_id=self.access_key,
             aws_secret_access_key=self.secret_key,
             endpoint_url=self.endpoint_url,
-            config=self.transfer_config,
+            config=CLIENT_CONFIG,
         )
         logger.info(str(self))
 
@@ -205,12 +187,13 @@ class ObjectClerk:
         Retrieves a bytes object from an S3 endpoint retrying connection errors
         according to object clerk instance attributes
         errors according to object_clerk definition
-        :param bucket: Bucket to retrieve the objext from
+        :param bucket: Bucket to retrieve the object from
         :param object_key: Key of the object in the bucket
-        :param verify_checksum: boolean to determine whether or not to verify the checksum of the retrieved bytes
-        against the etag
+        :param verify_checksum: boolean to determine whether or not to verify the
+          checksum of the retrieved bytes against the etag
         :return: bytes of the object retrieved
-        :raises: ObjectNotFoundException, ObjectClerkException, ObjectVerificationException, ObjectClerkServerAuthException
+        :raises: ObjectNotFoundException, ObjectClerkException, ObjectVerificationException,
+          ObjectClerkServerAuthException
         """
         response = retry_call(
             self._get_object,
@@ -320,7 +303,7 @@ class ObjectClerk:
             BytesIO(bytes_obj),
             Bucket=bucket,
             Key=object_key,
-            Config=self.transfer_config,
+            Config=UPLOAD_CONFIG,
             ExtraArgs={"ContentType": content_type},
         )
 
